aboutsummaryrefslogtreecommitdiff
path: root/src/types.ts
diff options
context:
space:
mode:
authorFlorian Dold <florian.dold@gmail.com>2017-05-31 16:04:14 +0200
committerFlorian Dold <florian.dold@gmail.com>2017-05-31 16:04:23 +0200
commit613a14c14f969bf21ff7569f93cde3a7a35ce96a (patch)
tree5767b5d1664e503aa46bfd37074c14f44402b806 /src/types.ts
parent7e5ddf3a456b0b39f688dc79035841d4bf86aa00 (diff)
downloadwallet-core-613a14c14f969bf21ff7569f93cde3a7a35ce96a.tar.xz
fix messaging, small issues and safer types
Diffstat (limited to 'src/types.ts')
-rw-r--r--src/types.ts18
1 files changed, 6 insertions, 12 deletions
diff --git a/src/types.ts b/src/types.ts
index 4dee93a10..82777f96b 100644
--- a/src/types.ts
+++ b/src/types.ts
@@ -1047,33 +1047,27 @@ export class Contract {
/**
* Offer record, stored in the wallet's database.
*/
@Checkable.Class()
-export class OfferRecord {
+export class ProposalRecord {
/**
* The contract that was offered by the merchant.
*/
@Checkable.Value(Contract)
- contract: Contract;
+ contractTerms: Contract;
/**
* Signature by the merchant over the contract details.
*/
@Checkable.String
- merchant_sig: string;
+ merchantSig: string;
/**
* Hash of the contract terms.
*/
@Checkable.String
- H_contract: string;
-
- /**
- * Time when the offer was made.
- */
- @Checkable.Number
- offer_time: number;
+ contractTermsHash: string;
/**
* Serial ID when the offer is stored in the wallet DB.
@@ -1085,7 +1079,7 @@ export class OfferRecord {
* Verify that a value matches the schema of this class and convert it into a
* member.
*/
- static checked: (obj: any) => OfferRecord;
+ static checked: (obj: any) => ProposalRecord;
}
@@ -1047,33 +1047,27 @@ export class Contract {
/**
- * Offer record, stored in the wallet's database.
+ * Proposal record, stored in the wallet's database.
*/